@@ -1,10 +1,10 @@
-from sqlalchemy import Boolean, Column, ForeignKey, Integer, String, ARRAY, PickleType
+from sqlalchemy import Boolean, Column, ForeignKey, Integer, String
 from sqlalchemy.orm import relationship
 from balance_domain.database.settings import Base
 
 
 class User(Base):
-    __tablename__ = "users"
+    __tablename__ = "TB_USER"
 
     id = Column(Integer, primary_key=True, index=True)
     surname = Column(String(255))
@@ -13,21 +13,21 @@ class User(Base):
     hashed_password = Column(String(255))
     is_active = Column(Boolean, default=True)
 
-    bank = relationship("Bank", back_populates="user")
+    bank = relationship("TB_BANK", back_populates="User")
 
     def to_json(self):
         return vars(self)
 
 
 class Bank(Base):
-    __tablename__ = "bank"
+    __tablename__ = "TB_BANK"
 
     id = Column(Integer, primary_key=True, index=True)
     token = Column(String(800))
-    user_id = Column(Integer, ForeignKey("users.id"))
+    user_id = Column(Integer, ForeignKey("TB_USER.id"))
     is_active = Column(Boolean, default=True)
 
-    user = relationship("User", back_populates="bank")
+    user = relationship("TB_USER", back_populates="Bank")
 
     def to_json(self):
         return vars(self)
